aboutsummaryrefslogtreecommitdiff
path: root/source/gfx.c
diff options
context:
space:
mode:
authoraliaspider2014-11-02 07:52:33 +0100
committeraliaspider2014-11-02 07:52:33 +0100
commit79a0fe978c6eece18d2e05320d6c86de584dbb48 (patch)
treea766b67e5ba37cd8bca19d15b3021af5cde2026a /source/gfx.c
parentd2c9eb147defae3d98df43730372dfce4a224cde (diff)
downloadsnes9x2005-79a0fe978c6eece18d2e05320d6c86de584dbb48.tar.gz
snes9x2005-79a0fe978c6eece18d2e05320d6c86de584dbb48.tar.bz2
snes9x2005-79a0fe978c6eece18d2e05320d6c86de584dbb48.zip
cleanups.
Diffstat (limited to 'source/gfx.c')
-rw-r--r--source/gfx.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/source/gfx.c b/source/gfx.c
index 303d09f..db89ec2 100644
--- a/source/gfx.c
+++ b/source/gfx.c
@@ -254,7 +254,7 @@ void DrawLargePixel16Sub1_2(uint32 Tile, int32 Offset,
uint32 StartPixel, uint32 Pixels,
uint32 StartLine, uint32 LineCount);
-bool8 S9xGraphicsInit()
+bool8 S9xInitGFX()
{
register uint32 PixelOdd = 1;
register uint32 PixelEven = 2;
@@ -532,9 +532,9 @@ bool8 S9xGraphicsInit()
return (TRUE);
}
-void S9xGraphicsDeinit(void)
+void S9xDeinitGFX(void)
{
// Free any memory allocated in S9xGraphicsInit
if (GFX.X2)
{
free((char*) GFX.X2);
@@ -532,9 +532,9 @@ bool8 S9xGraphicsInit()
{
- // Free any memory allocated in S9xGraphicsInit
+ // Free any memory allocated in S9xInitGFX
if (GFX.X2)
{